/////////////////////////////////////////////////////////////////////////////
// Name:        axsampleapp.h
// Purpose:     
// Author:      Julian Smart
// Modified by: 
// Created:     20/03/2009 15:46:38
// RCS-ID:      
// Copyright:   
// Licence:     New BSD License
/////////////////////////////////////////////////////////////////////////////

#ifndef _AXSAMPLEAPP_H_
#define _AXSAMPLEAPP_H_

/*!
 * Includes
 */

////@begin includes
#include "wx/image.h"
#include "mainframe.h"
////@end includes

#include "ax/ax_view.h"
#include "ax/ax_activator.h"

#include "ax_resource/ax_resource_library.h"

#include "commandeditor/commandeditor.h"
#include "shortcutcust/shortcutcust.h"

enum {
    SHOW_STATUS_MAXIMIZED,
    SHOW_STATUS_MINIMIZED,
    SHOW_STATUS_NORMAL
};

/*!
 * Forward declarations
 */

////@begin forward declarations
////@end forward declarations

/*!
 * Control identifiers
 */

////@begin control identifiers
////@end control identifiers

/*!
 * AxEditorCommandManager
 * Custom command manager
 */

class AxEditorCommandManager: public wxEditorCommandManager
{
public:
    AxEditorCommandManager() { }
    AxEditorCommandManager(const AxEditorCommandManager& manager) { Copy(manager); }

    /// Override this to implement default file launching
    virtual bool DefaultLaunchFile(const wxString& filename);
};

/*!
 * AxSampleApp class declaration
 */

class AxSampleApp: public wxApp
{    
    DECLARE_CLASS( AxSampleApp )
    DECLARE_EVENT_TABLE()

public:
    /// Constructor
    AxSampleApp();

    void Init();

    /// Initialises the application
    virtual bool OnInit();

    /// Called on exit
    virtual int OnExit();

    AxViewManager& GetViewManager() { return m_manager; }
    AxResourceLibrary& GetLibrary() { return m_library; }
    AxEditorCommandManager& GetCommandManager() { return m_commandManager; }
    wxShortcutManager& GetShortcutManager() { return m_shortcutManager; }

    /// Load and initialize commands
    void InitializeCommands();

    /// Load custom pronunciations.
    void LoadPronunciations();

    /// Save custom pronunciations.
    void SavePronunciations();

    /// Load settings
    bool LoadSettings();

    /// Save settings
    bool SaveSettings();

    /// Initialize custom shortcuts
    bool InitShortcuts();

////@begin AxSampleApp event handler declarations

////@end AxSampleApp event handler declarations

////@begin AxSampleApp member function declarations

////@end AxSampleApp member function declarations

////@begin AxSampleApp member variables
////@end AxSampleApp member variables

    AxViewManager           m_manager;
    AxResourceLibrary       m_library;
    AxEditorCommandManager  m_commandManager;
    wxShortcutManager       m_shortcutManager;

    wxRect                  m_frameRect;
    int                     m_frameStatus;
};

#define ID_STOP_SPEECH AxGetId(AxIdentifierStopSpeech)
#define ID_GO_HOME AxGetId(AxIdentifierGoHome)
#define ID_GO_UP AxGetId(AxIdentifierGoUp)
#define ID_DESCRIBE_CONTEXT AxGetId(AxIdentifierDescribeContext)
#define ID_DESCRIBE_ITEM AxGetId(AxIdentifierDescribeItem)

// For pop-up command menu (for choices of commands to edit or view the selected file)
#define ID_FILE_MENU_START      2100
#define ID_FILE_MENU_END        2150

/*!
 * Application instance declaration 
 */

////@begin declare app
DECLARE_APP(AxSampleApp)
////@end declare app

#endif
    // _AXSAMPLEAPP_H_
